@@ -11,7 +11,7 @@ from datetime import date, datetime
 from email.utils import formatdate
 from mimetypes import guess_type
 from pathlib import Path
-from typing import Tuple
+from typing import Iterable, Tuple
 from urllib import request
 from urllib.error import HTTPError, URLError
 from urllib.parse import urlencode, urlparse, urlunparse
@@ -227,6 +227,35 @@ class Util:
                 )
                 return None
 
+    def get_categories_from_meta(
+        self, in_page: Page, categories_labels: Iterable
+    ) -> tuple:
+        """Returns category from page meta.
+
+        :param in_page: input page to parse
+        :type in_page: Page
+        :param categories_labels: meta tags to look into
+        :type categories_labels: Iterable
+
+        :return: found categories
+        :rtype: tuple
+        """
+        if not categories_labels:
+            return None
+
+        output_categories = []
+        for category_label in categories_labels:
+            if category_label in in_page.meta:
+                if isinstance(in_page.meta.get(category_label), (list, tuple)):
+                    output_categories.extend(in_page.meta.get(category_label))
+                elif isinstance(in_page.meta.get(category_label), str):
+                    output_categories.append(in_page.meta.get(category_label))
+                else:
+                    pass
+            else:
+                continue
+        return sorted(output_categories)
+
     def get_date_from_meta(
         self, date_metatag_value: str, meta_datetime_format: str
     ) -> float:
@@ -481,6 +510,7 @@ class Util:
             filtered_pages.append(
                 {
                     "authors": page.authors,
+                    "categories": page.categories,
                     "comments_url": page.url_comments,
                     "description": page.description,
                     "guid": page.guid,
